==> expertai_nlapi-1.0.3-py3-none-any.whl: expertai/model/__init__.py <==
# Copyright (c) 2020 original authors
#
# Licensed under the Apache License, Version 2.0 (the License);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from expertai.model.atom import Atom
from expertai.model.position import Position
from expertai.model.category import Category
from expertai.model.data_model import DataModel
from expertai.model.dependency import Dependency
from expertai.model.entity import Entity
from expertai.model.entity_type import EntityType, ENTITY_TYPE_VALUES
from expertai.model.iptc import Iptc
from expertai.model.knowledge import Knowledge
from expertai.model.language import Language
from expertai.model.main_lemma import MainLemma
from expertai.model.main_phrase import MainPhrase
from expertai.model.main_sentence import MainSentence
from expertai.model.main_syncon import MainSyncon
from expertai.model.pos_tag import PosTag
from expertai.model.phrase_type import PhraseType
from expertai.model.phrase import Phrase
from expertai.model.eproperty import Property
from expertai.model.sentence import Sentence
from expertai.model.paragraph import Paragraph
from expertai.model.standard import Standard
from expertai.model.token import Token
from expertai.model.token_type import TokenType
from expertai.model.topic import Topic
from expertai.model.vsyncon import VSyncon

__all__ = [
    "Atom",
    "Category",
    "DataModel",
    "Dependency",
    "Entity",
    "EntityType",
    "ENTITY_TYPE_VALUES",
    "Iptc",
    "Property",
    "Knowledge",
    "Language",
    "MainLemma",
    "MainPhrase",
    "MainSentence",
    "MainSyncon",
    "Paragraph",
    "Phrase",
    "PhraseType",
    "Position",
    "PosTag",
    "Sentence",
    "Standard",
    "Token",
    "TokenType",
    "Topic",
    "VSyncon",
    ]

==> expertai_nlapi-1.2.4-py3-none-any.whl: expertai/model/__init__.py <==
# Copyright (c) 2020 original authors
#
# Licensed under the Apache License, Version 2.0 (the License);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from expertai.model.atom import Atom
from expertai.model.category import Category
from expertai.model.data_model import DataModel
from expertai.model.dependency import Dependency
from expertai.model.entity import Entity
from expertai.model.entity_type import ENTITY_TYPE_VALUES, EntityType
from expertai.model.eproperty import Property
from expertai.model.iptc import Iptc
from expertai.model.knowledge import Knowledge
from expertai.model.language import Language
from expertai.model.main_lemma import MainLemma
from expertai.model.main_phrase import MainPhrase
from expertai.model.main_sentence import MainSentence
from expertai.model.main_syncon import MainSyncon
from expertai.model.paragraph import Paragraph
from expertai.model.phrase import Phrase
from expertai.model.phrase_type import PhraseType
from expertai.model.pos_tag import PosTag
from expertai.model.position import Position
from expertai.model.sentence import Sentence
from expertai.model.standard import Standard
from expertai.model.token import Token
from expertai.model.token_type import TokenType
from expertai.model.topic import Topic
from expertai.model.vsyncon import VSyncon

__all__ = [
    "Atom",
    "Category",
    "DataModel",
    "Dependency",
    "Entity",
    "EntityType",
    "ENTITY_TYPE_VALUES",
    "Iptc",
    "Property",
    "Knowledge",
    "Language",
    "MainLemma",
    "MainPhrase",
    "MainSentence",
    "MainSyncon",
    "Paragraph",
    "Phrase",
    "PhraseType",
    "Position",
    "PosTag",
    "Sentence",
    "Standard",
    "Token",
    "TokenType",
    "Topic",
    "VSyncon",
]
